Qspi0

Struct Qspi0 

pub struct Qspi0 { /* private fields */ }
Quad Serial Peripheral Interface

Implementations

Source

impl Qspi0

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn sckdiv(&self) -> &Sckdiv

0x00 - Serial Clock Divisor Register

pub fn sckmode(&self) -> &Sckmode

0x04 - Serial Clock Mode Register

pub fn csid(&self) -> &Csid

0x10 - Chip Select ID Register

pub fn csdef(&self) -> &Csdef

0x14 - Chip Select Default Register

pub fn csmode(&self) -> &Csmode

0x18 - Chip Select Mode Register

pub fn delay0(&self) -> &Delay0

0x28 - Delay Control 0 Register

pub fn delay1(&self) -> &Delay1

0x2c - Delay Control 1 Register

pub fn fmt(&self) -> &Fmt

0x40 - Frame Format Register

pub fn txdata(&self) -> &Txdata

0x48 - Transmit Data Register

pub fn rxdata(&self) -> &Rxdata

0x4c - Receive Data Register

pub fn txmark(&self) -> &Txmark

0x50 - Transmit Watermark Register

pub fn rxmark(&self) -> &Rxmark

0x54 - Receive Watermark Register

pub fn fctrl(&self) -> &Fctrl

0x60 - SPI Flash Interface Control Register

pub fn ffmt(&self) -> &Ffmt

0x64 - SPI Flash Instruction Format Register

pub fn ie(&self) -> &Ie

0x70 - SPI Interrupt Enable Register

pub fn ip(&self) -> &Ip

0x74 - SPI Interrupt Pending Register